use serde_with::SerializeDisplay;

use crate::data::book::Format;

#[derive(Debug, Copy, Clone, SerializeDisplay)]
pub enum MediaType {
    Acquisition,
    Epub,
    Html,
    Jpeg,
    Navigation,
    Pdf,
    Text,
}

impl From<Format> for MediaType {
    fn from(value: Format) -> Self {
        match value.0.as_ref() {
            "epub" => MediaType::Epub,
            "pdf" => MediaType::Pdf,
            _ => MediaType::Text,
        }
    }
}

impl std::fmt::Display for MediaType {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            MediaType::Acquisition => write!(
                f,
                "application/atom+xml;profile=opds-catalog;kind=aqcuisition"
            ),
            MediaType::Epub => write!(f, "application/epub+zip"),
            MediaType::Html => write!(f, "text/html"),
            MediaType::Jpeg => write!(f, "image/jpeg"),
            MediaType::Navigation => write!(
                f,
                "application/atom+xml;profile=opds-catalog;kind=navigation"
            ),
            MediaType::Pdf => write!(f, "application/pdf"),
            MediaType::Text => write!(f, "text"),
        }
    }
}
